SystemOrganization addCategory: #GaruthaTinyBlog!

TBSMagritteReport subclass: #TBPostsReport
	instanceVariableNames: 'blog'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBPostsReport commentStamp: 'GabrielGermain 11/5/2018 21:11' prior: 0!
I'm a report of all posts.!

!TBPostsReport class methodsFor: 'reporting' stamp: 'GabrielGermain 11/5/2018 21:57'!
filteredDescriptionsFrom: aBlogPost
	^ aBlogPost magritteDescription
		select: [ :each | #(#title #category #date) includes: each accessor selector ]! !

!TBPostsReport class methodsFor: 'reporting' stamp: 'GabrielGermain 11/6/2018 22:55'!
from: aBlog
	| report blogPosts |
	blogPosts := aBlog allBlogPosts.
	report := self rows: blogPosts description: (self filteredDescriptionsFrom: blogPosts anyOne).
	report blog: aBlog.
	report
		addColumn:
			(MACommandColumn new
				addCommandOn: report selector: #viewPost: text: 'View';
				yourself;
				addCommandOn: report selector: #editPost: text: 'Edit';
				yourself;
				addCommandOn: report selector: #deletePost: text: 'Delete';
				yourself).
	^ report! !

!TBPostsReport methodsFor: 'actions' stamp: 'GabrielGermain 11/8/2018 22:33'!
addPost
	| post |
	post := self call: (self renderAddPostForm: TBPost new).
	post
		ifNotNil: [ blog writeBlogPost: post.
			self refreshReport ]! !

!TBPostsReport methodsFor: 'accessing' stamp: 'GabrielGermain 11/6/2018 22:52'!
blog
	^ blog! !

!TBPostsReport methodsFor: 'accessing' stamp: 'GabrielGermain 11/6/2018 22:52'!
blog: anObject
	blog := anObject! !

!TBPostsReport methodsFor: 'actions' stamp: 'GabrielGermain 11/8/2018 22:34'!
deletePost: aPost
	(self confirm: 'Do you want remove this post ?')
		ifTrue: [ blog removeBlogPost: aPost.
			self refreshReport ]! !

!TBPostsReport methodsFor: 'actions' stamp: 'GabrielGermain 11/8/2018 22:01'!
editPost: aPost
	| post |
	post := self call: (self renderEditPostForm: aPost).
	post ifNotNil: [ blog save ]! !

!TBPostsReport methodsFor: 'actions' stamp: 'GabrielGermain 11/8/2018 22:33'!
refreshReport
	self rows: blog allBlogPosts.
	self refresh! !

!TBPostsReport methodsFor: 'rendering' stamp: 'GabrielGermain 11/6/2018 22:42'!
renderAddPostForm: aPost
	^ aPost asComponent
		addDecoration:
			(TBSMagritteFormDecoration
				buttons:
					{(#save -> 'Add post').
					(#cancel -> 'Cancel')});
		yourself! !

!TBPostsReport methodsFor: 'rendering' stamp: 'GabrielGermain 11/6/2018 22:56'!
renderContentOn: html
	html tbsGlyphIcon perform: #iconPencil.
	html anchor
		callback: [ self addPost ];
		with: 'Add post'.
	super renderContentOn: html! !

!TBPostsReport methodsFor: 'rendering' stamp: 'GabrielGermain 11/6/2018 22:59'!
renderEditPostForm: aPost
	^ aPost asComponent
		addDecoration:
			(TBSMagritteFormDecoration
				buttons:
					{(#save -> 'Save post').
					(#cancel -> 'Cancel')});
		yourself! !

!TBPostsReport methodsFor: 'rendering' stamp: 'GabrielGermain 11/8/2018 22:28'!
renderViewPostForm: aPost
	^ aPost asComponent
		addDecoration: (TBSMagritteFormDecoration buttons: {(#cancel -> 'Back')});
		yourself! !

!TBPostsReport methodsFor: 'actions' stamp: 'GabrielGermain 11/8/2018 22:01'!
viewPost: aPost
	self call: (self renderViewPostForm: aPost)! !

TestCase subclass: #TBBlogTest
	instanceVariableNames: 'blog post first'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBBlogTest commentStamp: 'GabrielGermain 10/3/2018 22:22' prior: 0!
Tiny Blog tests!

!TBBlogTest methodsFor: 'setup - tear down' stamp: 'GabrielGermain 10/3/2018 22:37'!
setUp
	blog := TBBlog current.
	blog removeAllPosts.
	
	first := TBPost title: 'A title' text: 'A text' category: 'First Category'.
	blog writeBlogPost: first.
	
	post := (TBPost title: 'Another title' text: 'Another text' category: 'Second Category') beVisible.! !

!TBBlogTest methodsFor: 'setup - tear down' stamp: 'GabrielGermain 10/3/2018 22:39'!
tearDown
	TBBlog reset.! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 22:45'!
testAddBlogPost
	blog writeBlogPost: post.
	self assert: blog size equals: 2! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:11'!
testAllBlogPosts
	blog writeBlogPost: post.
	self assert: blog allBlogPosts size equals: 2! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:15'!
testAllBlogPostsFromCategory
	self assert: (blog allBlogPostsFromCategory: 'First Category')
	size equals: 1! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:19'!
testAllCategories
	blog writeBlogPost: post.
	self assert: blog allCategories size equals: 2! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:13'!
testAllVisibleBlogPosts
	blog writeBlogPost: post.
	self assert: blog allVisibleBlogPosts size equals: 1! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:17'!
testAllVisibleBlogPostsFromCategory
	blog writeBlogPost: post.
	self assert: (blog allVisibleBlogPostsFromCategory: 'First Category') size equals: 0.
	self assert: (blog allVisibleBlogPostsFromCategory: 'Second Category') size equals: 1! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:10'!
testRemoveAllBlogPosts
	blog removeAllPosts.
	self assert: blog size equals: 0! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 11/8/2018 22:32'!
testRemoveBlogPost
	self assert: blog size equals: 1.
	blog removeBlogPost: blog allBlogPosts anyOne.
	self assert: blog size equals: 0! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:10'!
testSize
	self assert: blog size equals: 1! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:19'!
testUnclassifiedBlogPosts
	self assert: (blog allBlogPosts select: [ :p | p isUnclassified ]) size equals: 0! !

WAComponent subclass: #TBApplicationRootComponent
	instanceVariableNames: 'main'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBApplicationRootComponent commentStamp: 'GabrielGermain 10/28/2018 21:45' prior: 0!
I'm the root component for the tiny blog application.!

!TBApplicationRootComponent class methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 21:49'!
canBeRoot
	^ true! !

!TBApplicationRootComponent class methodsFor: 'class initialization' stamp: 'GabrielGermain 11/13/2018 22:04'!
initialize
	"self initialize"

	| app |
	app := WAAdmin register: self asApplicationAt: 'TinyBlog'.
	app preferenceAt: #sessionClass put: TBSession.
	app
		addLibrary: JQDeploymentLibrary;
		addLibrary: JQUiDeploymentLibrary;
		addLibrary: TBSDeploymentLibrary! !

TBApplicationRootComponent initialize!

!TBApplicationRootComponent methodsFor: 'hooks' stamp: 'GabrielGermain 10/28/2018 22:11'!
children
	^ {main}! !

!TBApplicationRootComponent methodsFor: 'initialization' stamp: 'GabrielGermain 10/28/2018 22:16'!
initialize
	super initialize.
	main := TBPostsListComponent new! !

!TBApplicationRootComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 22:16'!
main: aComponent
	main := aComponent! !

!TBApplicationRootComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 22:10'!
renderContentOn: html
	html render: main! !

!TBApplicationRootComponent methodsFor: 'updating' stamp: 'GabrielGermain 10/28/2018 21:52'!
updateRoot: anHtmlRoot
	super updateRoot: anHtmlRoot.
	anHtmlRoot beHtml5.
	anHtmlRoot title: 'TinyBlog'! !

WAComponent subclass: #TBAuthentificationComponent
	instanceVariableNames: 'password account component'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBAuthentificationComponent commentStamp: 'GabrielGermain 10/29/2018 22:40' prior: 0!
I'm the authentication component.!

!TBAuthentificationComponent class methodsFor: 'initialize' stamp: 'GabrielGermain 10/29/2018 22:42'!
from: aComponent
	^ self new component: aComponent! !

!TBAuthentificationComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/29/2018 22:40'!
account
	^ account! !

!TBAuthentificationComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/29/2018 22:40'!
account: anObject
	account := anObject! !

!TBAuthentificationComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/29/2018 22:40'!
component
	^ component! !

!TBAuthentificationComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/29/2018 22:40'!
component: anObject
	component := anObject! !

!TBAuthentificationComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/29/2018 22:40'!
password
	^ password! !

!TBAuthentificationComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/29/2018 22:40'!
password: anObject
	password := anObject! !

!TBAuthentificationComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/29/2018 22:50'!
renderContentOn: html
	html tbsModal
		id: 'myAuthDialog';
		with: [ html
				tbsModalDialog: [ html
						tbsModalContent: [ self renderHeaderOn: html.
							html
								tbsModalBody: [ html
										form: [ self renderInputAccountOn: html.
											html break.
											self renderInputPasswordOn: html.
											html break.
											html break.
											html tbsModalFooter: [ self renderOkCancelOn: html ] ] ] ] ] ]! !

!TBAuthentificationComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/29/2018 22:46'!
renderHeaderOn: html
	html
		tbsModalHeader: [ html tbsModalCloseIcon.
			html tbsModalTitle
				level: 4;
				with: 'Authentification' ]! !

!TBAuthentificationComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/29/2018 22:47'!
renderInputAccountOn: html
	html text: 'Account:'.
	html break.
	html textInput
		callback: [ :value | account := value ];
		value: account! !

!TBAuthentificationComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/29/2018 22:49'!
renderInputPasswordOn: html
	html text: 'Password:'.
	html break.
	html passwordInput
		callback: [ :value | password := value ];
		value: password! !

!TBAuthentificationComponent methodsFor: 'rendering' stamp: 'GabrielGermain 11/13/2018 21:51'!
renderOkCancelOn: html
	html tbsSubmitButton
		"attributeAt: 'type' put: 'button';"
		callback: [ ];
		value: 'Cancel'.
	^ html tbsSubmitButton
		bePrimary;
		callback: [ self validate ];
		value: 'SignIn'! !

!TBAuthentificationComponent methodsFor: 'validation' stamp: 'GabrielGermain 11/13/2018 22:02'!
validate
	(self account = 'admin' and: [ self password = 'password' ])
		ifTrue: [ self session logged: true.
			self component gotoAdministration ]! !

WAComponent subclass: #TBCategoriesComponent
	instanceVariableNames: 'categories postsList'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBCategoriesComponent commentStamp: 'GabrielGermain 10/28/2018 22:55' prior: 0!
I'm responsible for displaying the list of categories.!

!TBCategoriesComponent class methodsFor: 'initialization' stamp: 'GabrielGermain 10/28/2018 22:57'!
categories: aCollectionOfCategories postsList: aTBScreen
	^ self new
		categories: aCollectionOfCategories;
		postsList: aTBScreen! !

!TBCategoriesComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 22:56'!
categories
	^ categories! !

!TBCategoriesComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 23:17'!
categories: anObject
	categories := anObject asOrderedCollection.
	categories add: 'All'.
	categories := categories sort! !

!TBCategoriesComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 22:56'!
postsList
	^ postsList! !

!TBCategoriesComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 22:56'!
postsList: anObject
	postsList := anObject! !

!TBCategoriesComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 23:06'!
renderCategoryLinkOn: html with: aCategory
	html tbsLinkifyListGroupItem
		class: 'active' if: aCategory = self postsList currentCategory;
		callback: [ self selectCategory: aCategory ];
		with: aCategory! !

!TBCategoriesComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 23:00'!
renderContentOn: html
	html
		tbsListGroup: [ html tbsListGroupItem with: [ html strong: 'Categories' ].
			categories do: [ :cat | self renderCategoryLinkOn: html with: cat ] ]! !

!TBCategoriesComponent methodsFor: 'action' stamp: 'GabrielGermain 10/28/2018 22:57'!
selectCategory: aCategory
	postsList currentCategory: aCategory! !

WAComponent subclass: #TBHeaderComponent
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBHeaderComponent commentStamp: 'GabrielGermain 10/28/2018 22:02' prior: 0!
I'm the header for the TB application.!

!TBHeaderComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 22:02'!
renderContentOn: html
	html tbsNavbar beDefault
		with: [ html tbsNavbarBrand
				url: '#';
				with: 'TinyBlog' ]! !

WAComponent subclass: #TBPostComponent
	instanceVariableNames: 'post'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBPostComponent commentStamp: 'GabrielGermain 10/28/2018 22:47' prior: 0!
I'm a Post component.!

!TBPostComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 22:48'!
date
	^ post date! !

!TBPostComponent methodsFor: 'initialization' stamp: 'GabrielGermain 10/28/2018 22:47'!
initialize
	super initialize.
	post := TBPost new! !

!TBPostComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 22:52'!
post: aPost
	post := aPost! !

!TBPostComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 22:49'!
renderContentOn: html
	html heading
		level: 2;
		with: self title.
	html heading
		level: 6;
		with: self date.
	html text: self text! !

!TBPostComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 22:48'!
text
	^ post text! !

!TBPostComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 22:48'!
title
	^ post title! !

WAComponent subclass: #TBScreenComponent
	instanceVariableNames: 'header'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBScreenComponent commentStamp: 'GabrielGermain 10/28/2018 21:55' prior: 0!
I'm an abstract class class defining common behaviour for the TB application.!

TBScreenComponent subclass: #TBAdminComponent
	instanceVariableNames: 'report'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBAdminComponent commentStamp: 'GabrielGermain 10/29/2018 23:02' prior: 0!
I'm the TB admin component.!

!TBAdminComponent methodsFor: 'hooks' stamp: 'GabrielGermain 11/5/2018 21:15'!
children
	^ super children copyWith: self report! !

!TBAdminComponent methodsFor: 'initialization' stamp: 'GabrielGermain 11/5/2018 21:19'!
initialize
	super initialize.
	self report: (TBPostsReport from: self blog)! !

!TBAdminComponent methodsFor: 'rendering' stamp: 'GabrielGermain 11/13/2018 19:43'!
renderContentOn: html
	super renderContentOn: html.
	html
		tbsContainer: [ html heading: 'Blog Admin'.
			html tbsGlyphIcon perform: #iconEyeOpen.
			html anchor
				callback: [ self answer ];
				with: 'Public Area'.
			html horizontalRule.
			html render: self report ]! !

!TBAdminComponent methodsFor: 'accessing' stamp: 'GabrielGermain 11/5/2018 21:14'!
report
	^ report! !

!TBAdminComponent methodsFor: 'accessing' stamp: 'GabrielGermain 11/5/2018 21:14'!
report: anObject
	report := anObject! !

TBScreenComponent subclass: #TBPostsListComponent
	instanceVariableNames: 'currentCategory'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBPostsListComponent commentStamp: 'GabrielGermain 10/28/2018 22:14' prior: 0!
I'm a component displaying the list of posts.!

!TBPostsListComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 23:10'!
basicRenderCategoriesOn: html
	^ html render: (TBCategoriesComponent categories: self blog allCategories postsList: self)! !

!TBPostsListComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 23:10'!
basicRenderPostsOn: html
	^ self readSelectedPosts do: [ :p | html render: (TBPostComponent new post: p) ]! !

!TBPostsListComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 22:58'!
currentCategory
	^ currentCategory! !

!TBPostsListComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 23:39'!
currentCategory: anObject
	currentCategory := anObject.! !

!TBPostsListComponent methodsFor: 'action' stamp: 'GabrielGermain 10/29/2018 23:03'!
gotoAdministration
	self call: TBAdminComponent new! !

!TBPostsListComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 23:40'!
readSelectedPosts
	|all|
	all := self currentCategory isNil or: self currentCategory = 'All'.
	^ all ifTrue: [ self blog allVisibleBlogPosts ] ifFalse: [ self blog allVisibleBlogPostsFromCategory: self currentCategory ]! !

!TBPostsListComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/29/2018 22:57'!
renderCategoryColumnOn: html
	html tbsColumn
		extraSmallSize: 12;
		smallSize: 2;
		mediumSize: 4;
		with: [ self basicRenderCategoriesOn: html.
			self renderSignInOn: html ]! !

!TBPostsListComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/29/2018 22:55'!
renderContentOn: html
	super renderContentOn: html.
	html render: (TBAuthentificationComponent from: self).
	html
		tbsContainer: [ html tbsRow
				showGrid;
				with: [ self renderCategoryColumnOn: html.
					self renderPostColumnOn: html ] ]! !

!TBPostsListComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 23:10'!
renderPostColumnOn: html
	^ html tbsColumn
		extraSmallSize: 12;
		smallSize: 10;
		mediumSize: 8;
		with: [ self basicRenderPostsOn: html ]! !

!TBPostsListComponent methodsFor: 'rendering' stamp: 'GabrielGermain 11/13/2018 21:59'!
renderSignInOn: html
	self session isLogged
		ifFalse: [ html tbsGlyphIcon perform: #iconLock.
			html
				html:
					'<a data-toggle="modal" href="#myAuthDialog"
class="link">SignIn</a>' ]
		ifTrue: [ html tbsGlyphIcon perform: #iconUser.
			html anchor
				callback: [ self gotoAdministration ];
				with: 'Private area' ]! !

!TBScreenComponent methodsFor: 'accessing' stamp: 'GabrielGermain 10/28/2018 21:56'!
blog
	"Return the current blog in the future we will ask the
session to return the blog of the currently logged user."

	^ TBBlog current! !

!TBScreenComponent methodsFor: 'hooks' stamp: 'GabrielGermain 10/28/2018 22:07'!
children
	^ OrderedCollection with: header! !

!TBScreenComponent methodsFor: 'initialization' stamp: 'GabrielGermain 10/28/2018 22:05'!
initialize
	super initialize.
	header := TBHeaderComponent new! !

!TBScreenComponent methodsFor: 'rendering' stamp: 'GabrielGermain 10/28/2018 22:09'!
renderContentOn: html
	html render: header! !

WASession subclass: #TBSession
	instanceVariableNames: 'logged'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBSession commentStamp: 'GabrielGermain 11/8/2018 22:50' prior: 0!
I'm a TinyBlog session.!

!TBSession methodsFor: 'initialization' stamp: 'GabrielGermain 11/8/2018 22:51'!
initialize
	super initialize.
	self logged: false! !

!TBSession methodsFor: 'accessing' stamp: 'GabrielGermain 11/8/2018 22:51'!
isLogged
	^ self logged! !

!TBSession methodsFor: 'accessing' stamp: 'GabrielGermain 11/8/2018 22:51'!
logged
	^ logged! !

!TBSession methodsFor: 'accessing' stamp: 'GabrielGermain 11/8/2018 22:51'!
logged: anObject
	logged := anObject! !

Object subclass: #TBBlog
	instanceVariableNames: 'posts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

TBBlog class
	instanceVariableNames: 'uniqueInstance'!

!TBBlog commentStamp: 'GabrielGermain 10/3/2018 22:02' prior: 0!
I'm a Tiny Blog.!

TBBlog class
	instanceVariableNames: 'uniqueInstance'!

!TBBlog class methodsFor: 'initialize - release' stamp: 'GabrielGermain 10/16/2018 23:50'!
createDemoPosts
	"TBBlog createDemoPosts"

	self current
		writeBlogPost:
			((TBPost
				title: 'Welcome in TinyBlog'
				text: 'TinyBlog is a small blog engine made with Pharo.'
				category: 'TinyBlog') visible: true);
		writeBlogPost:
			((TBPost
				title: 'Report Pharo Sprint'
				text:
					'Friday, June 12 there was a Pharo sprint / Moose dojo. It was a
nice event with more than 15 motivated sprinters. With the help
of candies, cakes and chocolate, huge work has been done'
				category: 'Pharo') visible: true);
		writeBlogPost:
			((TBPost
				title:
					'Brick on top of Bloc -
Preview'
				text:
					'We are happy to announce the first preview
version of Brick, a new widget set created from scratch on top
of Bloc. Brick is being developed primarily by Alex Syrel
(together with Alain Plantec, Andrei Chis and myself), and the
work is sponsored by ESUG.
Brick is part of the Glamorous Toolkit effort and will provide
the basis for the new versions of the development tools.'
				category: 'Pharo') visible: true);
		writeBlogPost:
			((TBPost
				title:
					'The sad story of unclassified
blog posts'
				text: 'So sad that I can read this.') visible: true);
		writeBlogPost:
			((TBPost
				title:
					'Working with Pharo on the
Raspberry Pi'
				text:
					'Hardware is getting cheaper and many new
small devices like the famous Raspberry Pi provide new
computation power that was one once only available on regular
desktop computers.'
				category: 'Pharo') visible: true)! !

!TBBlog class methodsFor: 'initialize - release' stamp: 'GabrielGermain 11/3/2018 18:19'!
current
	^ self selectAll ifNotEmpty: [ :x | x anyOne ] ifEmpty: [ self new save ]! !

!TBBlog class methodsFor: 'initialize' stamp: 'GabrielGermain 11/3/2018 18:16'!
initialize
	self reset! !

TBBlog initialize!

!TBBlog class methodsFor: 'voyage' stamp: 'GabrielGermain 11/4/2018 12:01'!
initializeLocalhostMongoDB
	| repository |
	repository := VOMongoRepository database: 'tinyblog'.
	repository enableSingleton! !

!TBBlog class methodsFor: 'voyage' stamp: 'GabrielGermain 11/3/2018 18:15'!
initializeVoyageOnMemoryDB
	VOMemoryRepository new enableSingleton! !

!TBBlog class methodsFor: 'voyage' stamp: 'GabrielGermain 11/3/2018 18:14'!
isVoyageRoot
	"Indicates that instances of this class are top level document in
noSQL databases"

	^ true! !

!TBBlog class methodsFor: 'initialize' stamp: 'GabrielGermain 11/4/2018 22:36'!
reset
	self initializeVoyageOnMemoryDB ! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:12'!
allBlogPosts
	^ posts! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:16'!
allBlogPostsFromCategory: aCategory
	^ posts select: [ :p | p category = aCategory ]! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:21'!
allCategories
	^ (posts collect: [ :p | p category ]) asSet! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:14'!
allVisibleBlogPosts
	^ posts select: [ :p | p isVisible ]! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:18'!
allVisibleBlogPostsFromCategory: aCategory
	^ posts select: [ :p | p category = aCategory and: [ p isVisible ] ]! !

!TBBlog methodsFor: 'initialize' stamp: 'GabrielGermain 10/3/2018 22:04'!
initialize
	super initialize.
	posts := OrderedCollection new.! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 11/3/2018 18:21'!
removeAllPosts
	posts := OrderedCollection new.
	self save! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 11/8/2018 22:31'!
removeBlogPost: aPost
	posts remove: aPost ifAbsent: [ ].
	self save! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:09'!
size
	^ posts size.! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 11/3/2018 18:20'!
writeBlogPost: aPost
	"Write the blog post in database"

	self allBlogPosts add: aPost.
	self save! !

Object subclass: #TBPost
	instanceVariableNames: 'title text date category visible'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBPost commentStamp: 'GabrielGermain 9/21/2018 00:23' prior: 0!
I'm a Tiny Blog Post!

!TBPost class methodsFor: 'initialize' stamp: 'GabrielGermain 9/21/2018 00:33'!
title: aTitle text: aText
	^ self new
		title: aTitle;
		text: aText;
		yourself! !

!TBPost class methodsFor: 'initialize' stamp: 'GabrielGermain 9/21/2018 00:35'!
title: aTitle text: aText category: aCategory
	^ (self title: aTitle text: aText)
		category: aCategory;
		yourself! !

!TBPost class methodsFor: 'definition' stamp: 'GabrielGermain 9/21/2018 00:30'!
unclassifiedTag
	^ 'Unclassified'! !

!TBPost methodsFor: 'action' stamp: 'GabrielGermain 9/21/2018 00:31'!
beVisible
	self visible: true! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:24'!
category
	^ category! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:24'!
category: anObject
	category := anObject! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:25'!
date
	^ date! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:25'!
date: anObject
	date := anObject! !

!TBPost methodsFor: 'description' stamp: 'GabrielGermain 11/8/2018 22:43'!
descriptionCategory
	<magritteDescription>
	^ MAStringDescription new
		label: 'Category';
		priority: 300;
		accessor: #category;
		comment: 'Unclassified if empty';
		componentClass: TBSMagritteTextInputComponent;
		yourself! !

!TBPost methodsFor: 'description' stamp: 'GabrielGermain 11/8/2018 22:39'!
descriptionContainer
	<magritteContainer>
	^ super descriptionContainer
		componentRenderer: TBSMagritteFormRenderer;
		yourself! !

!TBPost methodsFor: 'description' stamp: 'GabrielGermain 11/5/2018 22:06'!
descriptionDate
	<magritteDescription>
	^ MADateDescription new
		label: 'Date';
		priority: 400;
		accessor: #date;
		beRequired;
		yourself! !

!TBPost methodsFor: 'description' stamp: 'GabrielGermain 11/8/2018 22:43'!
descriptionText
	<magritteDescription>
	^ MAMemoDescription new
		label: 'Text';
		priority: 200;
		accessor: #text;
		requiredErrorMessage: 'A blog post must contain a text.';
		comment: 'Please enter a text';
		componentClass: TBSMagritteTextAreaComponent;
		beRequired;
		yourself! !

!TBPost methodsFor: 'description' stamp: 'GabrielGermain 11/8/2018 22:41'!
descriptionTitle
	<magritteDescription>
	^ MAStringDescription new
		label: 'Title';
		priority: 100;
		accessor: #title;
		requiredErrorMessage: 'A blog post must have a title.';
		comment: 'Please enter a title';
		componentClass: TBSMagritteTextInputComponent;
		beRequired;
		yourself! !

!TBPost methodsFor: 'description' stamp: 'GabrielGermain 11/8/2018 22:44'!
descriptionVisible
	<magritteDescription>
	^ MABooleanDescription new
		label: 'Visible';
		priority: 500;
		accessor: #visible;
		componentClass: TBSMagritteCheckboxComponent;
		beRequired;
		yourself! !

!TBPost methodsFor: 'initialize' stamp: 'GabrielGermain 9/21/2018 00:31'!
initialize
	self category: TBPost unclassifiedTag.
	self date: Date today.
	self notVisible! !

!TBPost methodsFor: 'action' stamp: 'GabrielGermain 9/21/2018 00:38'!
isUnclassified
	^ self category = TBPost unclassifiedTag! !

!TBPost methodsFor: 'action' stamp: 'GabrielGermain 9/21/2018 00:31'!
isVisible
	^ self visible! !

!TBPost methodsFor: 'action' stamp: 'GabrielGermain 9/21/2018 00:31'!
notVisible
	self visible: false! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:24'!
text
	^ text! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:24'!
text: anObject
	text := anObject! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:25'!
title
	^ title! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:25'!
title: anObject
	title := anObject! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:25'!
visible
	^ visible! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:25'!
visible: anObject
	visible := anObject! !

Object subclass: #TBTeapotWebApp
	instanceVariableNames: 'teapot'
	classVariableNames: 'Server'
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBTeapotWebApp commentStamp: 'GabrielGermain 10/10/2018 22:24' prior: 0!
I'm the teapot webapp for the tiny blog.!

!TBTeapotWebApp class methodsFor: 'starting/stopping' stamp: 'GabrielGermain 10/10/2018 22:39'!
start
	Server ifNil: [ Server := self new start ]! !

!TBTeapotWebApp class methodsFor: 'starting/stopping' stamp: 'GabrielGermain 10/10/2018 22:40'!
stop
	Server ifNotNil: [ Server stop. Server := nil ]! !

!TBTeapotWebApp methodsFor: 'accessing' stamp: 'GabrielGermain 10/16/2018 23:45'!
allPosts
	^ TBBlog current allVisibleBlogPosts! !

!TBTeapotWebApp methodsFor: 'rendering' stamp: 'GabrielGermain 10/16/2018 23:51'!
errorPage
	^ String
		streamContents: [ :s | 
			self renderPageHeaderOn: s.
			s << '<p>Oups, an error occurred</p>'.
			self renderPageFooterOn: s ]! !

!TBTeapotWebApp methodsFor: 'rendering' stamp: 'GabrielGermain 10/17/2018 00:02'!
homePage
	^ String
		streamContents: [ :s | 
			self renderPageHeaderOn: s.
			s << '<h1>TinyBlog Web App</h1>'.
			s << '<ul>'.
			self allPosts
				withIndexDo: [ :aPost :index | 
					s
						<< '<li>';
						<< ('<a href="/post/' , index asString , '">');
						<< aPost title;
						<< '</a></li>' ].
			s << '</ul>'.
			self renderPageFooterOn: s ]! !

!TBTeapotWebApp methodsFor: 'initialization' stamp: 'GabrielGermain 10/10/2018 22:30'!
initialize
	super initialize.
	teapot := Teapot configure: {
		#port -> 8081.
		#debugMode -> true
	}.! !

!TBTeapotWebApp methodsFor: 'rendering' stamp: 'GabrielGermain 10/16/2018 23:58'!
pageForPostNumber: aPostNumber
	| currentPost |
	currentPost := self allPosts at: aPostNumber ifAbsent: [ ^ self errorPage ].
	^ String
		streamContents: [ :s | 
			self renderPageHeaderOn: s.
			s << ('<h1>' , currentPost title , '</h1>').
			s << ('<h3>' , currentPost date mmddyyyy , '</h3>').
			s << ('<p> Category: ' , currentPost category , '</p>').
			s << ('<p>' , currentPost text , '</p>').
			self renderPageFooterOn: s ]! !

!TBTeapotWebApp methodsFor: 'rendering' stamp: 'GabrielGermain 10/16/2018 23:47'!
renderPageFooterOn: aStream
	aStream << '</body></html>'! !

!TBTeapotWebApp methodsFor: 'rendering' stamp: 'GabrielGermain 10/16/2018 23:47'!
renderPageHeaderOn: aStream
	aStream << '<html><body>'! !

!TBTeapotWebApp methodsFor: 'starting/stopping' stamp: 'GabrielGermain 10/16/2018 23:53'!
start
	teapot
		GET: '/' -> [ self homePage ];
		GET: '/post/<id>' -> [ :request | self pageForPostNumber: (request at: #id) asNumber ];
		start! !

!TBTeapotWebApp methodsFor: 'starting/stopping' stamp: 'GabrielGermain 10/10/2018 22:34'!
stop
	teapot stop.! !

TBBlog initialize!

TBApplicationRootComponent initialize!
